==> riskservice-client-1.2.4-sources.jar: cn/fraudmetrix/riskservice/ruledetail/ConditionDetail.java <==
package cn.fraudmetrix.riskservice.ruledetail;

import java.io.Serializable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.alibaba.fastjson.JSONObject;

public abstract class ConditionDetail extends DetailBase implements Serializable {

    private static final Log logger = LogFactory.getLog(ConditionDetail.class);

    private String type;

    public ConditionDetail(){
    }

    public ConditionDetail(String type){
        this.type = type;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public static Class<?> getType(JSONObject json) {
        try {
            if(json == null) return null;
            String type = json.getString("type");
            if (type == null) return null;
            return dispatchType(type, json);
        } catch (Exception ex) {
            logger.warn("Failed to parse condition detail", ex);
            return null;
        }
    }

    private static Class<?> dispatchType(String type, JSONObject json) {
        if (type == null) return null;
        if (json == null) return null;
        if (type.equals("frequency_one_dim")) return FrequencyOneDimDetail.class;
        if (type.equals("frequency_count")) return FrequencyCountDetail.class;
        if (type.equals("frequency_distinct")) return FrequencyDistinctDetail.class;
        if (type.equals("black_list")) return BlackListDetail.class;
        if (type.equals("fp_exception")) return  FpExceptionDetail.class;
        if (type.equals("grey_list")) return GreyListDetail.class;
        if (type.equals("fuzzy_black_list")) return FuzzyBlackListDetail.class;
        if (type.equals("geo_ip_distance")) return GeoIpDistanceDetail.class;
        if (type.equals("proxy_ip")) return ProxyIpDetail.class;
        if (type.equals("match_address")) return MatchAddressDetail.class;
        if (type.equals("gps_distance")) return GpsDistanceDetail.class;
        if (type.equals("custom_list")) return CustomListDetail.class;
        if (type.equals("regex")) return RegexDetail.class;
        if (type.equals("event_time_diff")) return EventTimeDiffDetail.class;
        if (type.equals("time_diff")) return TimeDiffDetail.class;
        if (type.equals("active_days_one")) return ActiveDaysOneDetail.class;
        if (type.equals("active_days_two")) return ActiveDaysTwoDetail.class;
        if (type.equals("cross_event")) return CrossEventDetail.class;
        if (type.equals("cross_velocity_distinct")) return CrossVelocityDistinctDetail.class;
        if (type.equals("cross_velocity_count")) return CrossVelocityCountDetail.class;
        if (type.equals("cross_velocity_one_dim")) return CrossVelocityOneDimDetail.class;
        if (type.equals("calculate")) return CalculateDetail.class;
        if (type.equals("last_match")) return LastMatchDetail.class;
        if (type.equals("min_max")) return MinMaxDetail.class;
        if (type.equals("count")) return CountDetail.class;
        if (type.equals("discredit_count")) return CountDiscreditDetail.class;
        if (type.equals("association_partner")) return AssociationPartnerDetail.class;
        if (type.equals("count_discredit")) return CountDiscreditDetail.class;
        if (type.equals("cross_partner")) return CrossPartnerDetail.class;
        if (type.equals("four_calculation")) return FourCalculationDetail.class;
        if (type.equals("function_kit")) return FunctionKitDetail.class;
        if (type.equals("usual_browser")) return UsualBrowserDetail.class;
        if (type.equals("usual_device")) return UsualDeviceDetail.class;
        if (type.equals("usual_location")) return UsualLocationDetail.class;
        logger.warn("Unknown condition detail type: " + type);
        return null;
    }
}

==> riskservice-client-1.2.5-sources.jar: cn/fraudmetrix/riskservice/ruledetail/ConditionDetail.java <==
package cn.fraudmetrix.riskservice.ruledetail;

import java.io.Serializable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.alibaba.fastjson.JSONObject;

public abstract class ConditionDetail extends DetailBase implements Serializable {

    private static final Log logger = LogFactory.getLog(ConditionDetail.class);

    private String type;

    public ConditionDetail(){
    }

    public ConditionDetail(String type){
        this.type = type;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public static Class<?> getType(JSONObject json) {
        try {
            if(json == null) return null;
            String type = json.getString("type");
            if (type == null) return null;
            return dispatchType(type, json);
        } catch (Exception ex) {
            logger.warn("Failed to parse condition detail", ex);
            return null;
        }
    }

    private static Class<?> dispatchType(String type, JSONObject json) {
        if (type == null) return null;
        if (json == null) return null;
        if (type.equals("frequency_one_dim")) return FrequencyOneDimDetail.class;
        if (type.equals("frequency_count")) return FrequencyCountDetail.class;
        if (type.equals("frequency_distinct")) return FrequencyDistinctDetail.class;
        if (type.equals("black_list")) return BlackListDetail.class;
        if (type.equals("fp_exception")) return  FpExceptionDetail.class;
        if (type.equals("grey_list")) return GreyListDetail.class;
        if (type.equals("fuzzy_black_list")) return FuzzyBlackListDetail.class;
        if (type.equals("geo_ip_distance")) return GeoIpDistanceDetail.class;
        if (type.equals("proxy_ip")) return ProxyIpDetail.class;
        if (type.equals("match_address")) return MatchAddressDetail.class;
        if (type.equals("gps_distance")) return GpsDistanceDetail.class;
        if (type.equals("custom_list")) return CustomListDetail.class;
        if (type.equals("regex")) return RegexDetail.class;
        if (type.equals("event_time_diff")) return EventTimeDiffDetail.class;
        if (type.equals("time_diff")) return TimeDiffDetail.class;
        if (type.equals("active_days_one")) return ActiveDaysOneDetail.class;
        if (type.equals("active_days_two")) return ActiveDaysTwoDetail.class;
        if (type.equals("cross_event")) return CrossEventDetail.class;
        if (type.equals("cross_velocity_distinct")) return CrossVelocityDistinctDetail.class;
        if (type.equals("cross_velocity_count")) return CrossVelocityCountDetail.class;
        if (type.equals("cross_velocity_one_dim")) return CrossVelocityOneDimDetail.class;
        if (type.equals("calculate")) return CalculateDetail.class;
        if (type.equals("last_match")) return LastMatchDetail.class;
        if (type.equals("min_max")) return MinMaxDetail.class;
        if (type.equals("count")) return CountDetail.class;
        if (type.equals("discredit_count")) return CountDiscreditDetail.class;
        if (type.equals("association_partner")) return AssociationPartnerDetail.class;
        if (type.equals("count_discredit")) return CountDiscreditDetail.class;
        if (type.equals("cross_partner")) return CrossPartnerDetail.class;
        if (type.equals("four_calculation")) return FourCalculationDetail.class;
        if (type.equals("function_kit")) return FunctionKitDetail.class;
        if (type.equals("usual_browser")) return UsualBrowserDetail.class;
        if (type.equals("usual_device")) return UsualDeviceDetail.class;
        if (type.equals("usual_location")) return UsualLocationDetail.class;
        if (type.equals("association_industry")) return AssociationIndustryDetail.class;
        if (type.equals("keyword")) return KeywordDetail.class;
        logger.warn("Unknown condition detail type: " + type);
        return null;
    }
}
